from django.test import TestCase


class MigrationsCheck(TestCase):
    def setUp(self):
        from django.utils import translation
        self.saved_locale = translation.get_language()
        translation.deactivate_all()

    def tearDown(self):
        if self.saved_locale is not None:
            from django.utils import translation
            translation.activate(self.saved_locale)

    def test_missing_migrations(self):
        from django.db import connection
        from django.apps.registry import apps
        from django.db.migrations.executor import MigrationExecutor
        executor = MigrationExecutor(connection)
        from django.db.migrations.autodetector import MigrationAutodetector
        from django.db.migrations.state import ProjectState
        autodetector = MigrationAutodetector(
            executor.loader.project_state(),
            ProjectState.from_apps(apps),
        )
        changes = autodetector.changes(graph=executor.loader.graph)
        self.assertEqual({}, changes)



from __future__ import unicode_literals

from django.db import models
from django.utils.translation import gettext_lazy as _


class CommonAccess(models.Model):
    user_agent = models.CharField(
        _('User Agent'),
        max_length=255,
        db_index=True,
    )

    ip_address = models.GenericIPAddressField(
        _('IP Address'),
        null=True,
        db_index=True,
    )

    username = models.CharField(
        _('Username'),
        max_length=255,
        null=True,
        db_index=True,
    )

    # Once a user logs in from an ip, that combination is trusted and not
    # locked out in case of a distributed attack
    trusted = models.BooleanField(
        default=False,
        db_index=True,
    )

    http_accept = models.CharField(
        _('HTTP Accept'),
        max_length=1025,
    )

    path_info = models.CharField(
        _('Path'),
        max_length=255,
    )

    attempt_time = models.DateTimeField(
        _('Attempt Time'),
        auto_now_add=True,
    )

    class Meta(object):
        app_label = 'axes'
        abstract = True
        ordering = ['-attempt_time']


class AccessAttempt(CommonAccess):
    get_data = models.TextField(
        _('GET Data'),
    )

    post_data = models.TextField(
        _('POST Data'),
    )

    failures_since_start = models.PositiveIntegerField(
        _('Failed Logins'),
    )

    @property
    def failures(self):
        return self.failures_since_start

    def __str__(self):
        return 'Attempted Access: %s' % self.attempt_time

    class Meta(object):
        verbose_name = _('access attempt')
        verbose_name_plural = _('access attempts')

class AccessLog(CommonAccess):
    logout_time = models.DateTimeField(
        _('Logout Time'),
        null=True,
        blank=True,
    )

    def __str__(self):
        return 'Access Log for %s @ %s' % (self.username, self.attempt_time)

    class Meta(object):
        verbose_name = _('access log')
        verbose_name_plural = _('access logs')



from __future__ import unicode_literals

from django.conf import settings
from django.utils.translation import gettext_lazy as _

from appconf import AppConf


class MyAppConf(AppConf):
    # see if the user has overridden the failure limit
    FAILURE_LIMIT = 3

    # see if the user has set axes to lock out logins after failure limit
    LOCK_OUT_AT_FAILURE = True

    USE_USER_AGENT = False

    # use a specific username field to retrieve from login POST data
    USERNAME_FORM_FIELD = 'username'

    # use a specific password field to retrieve from login POST data
    PASSWORD_FORM_FIELD = 'password'

    # use a provided callable to transform the POSTed username into the one used in credentials
    USERNAME_CALLABLE = None

    # only check user name and not location or user_agent
    ONLY_USER_FAILURES = False

    # lock out user from particular IP based on combination USER+IP
    LOCK_OUT_BY_COMBINATION_USER_AND_IP = False

    DISABLE_ACCESS_LOG = False

    DISABLE_SUCCESS_ACCESS_LOG = False

    LOGGER = 'axes.watch_login'

    LOCKOUT_TEMPLATE = None

    LOCKOUT_URL = None

    COOLOFF_TIME = None

    VERBOSE = True

    # whitelist and blacklist
    # TODO: convert the strings to IPv4 on startup to avoid type conversion during processing
    NEVER_LOCKOUT_WHITELIST = False

    ONLY_WHITELIST = False

    IP_WHITELIST = None

    IP_BLACKLIST = None

    # message to show when locked out and have cooloff enabled
    COOLOFF_MESSAGE = _('Account locked: too many login attempts. Please try again later')

    # message to show when locked out and have cooloff disabled
    PERMALOCK_MESSAGE = _('Account locked: too many login attempts. Contact an admin to unlock your account.')

    # if your deployment is using reverse proxies, set this value to 'left-most' or 'right-most' per your configuration
    PROXY_ORDER = 'left-most'

    # if your deployment is using reverse proxies, set this value to the number of proxies in front of Django
    PROXY_COUNT = None

    # if your deployment is using reverse proxies, set to your trusted proxy IP addresses prefixes if needed
    PROXY_TRUSTED_IPS = None

    # set to the names of request.META attributes that should be checked for the IP address of the client
    # if your deployment is using reverse proxies, ensure that the header attributes are securely set by the proxy
    # ensure that the client can not spoof the headers by setting them and sending them through the proxy
    META_PRECEDENCE_ORDER = getattr(
        settings, 'AXES_META_PRECEDENCE_ORDER', getattr(
            settings, 'IPWARE_META_PRECEDENCE_ORDER', (
                'REMOTE_ADDR',
            )
        )
    )



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from __future__ import unicode_literals

import codecs
from setuptools import setup, find_packages

from axes import get_version

setup(
    name='django-axes',
    version=get_version(),
    description='Keep track of failed login attempts in Django-powered sites.',
    long_description=(
        codecs.open('README.rst', encoding='utf-8').read() + '\n' +
        codecs.open('CHANGES.txt', encoding='utf-8').read()),
    keywords='authentication django pci security'.split(),
    author='Josh VanderLinden, Philip Neustrom, Michael Blume, Camilo Nova',
    author_email='codekoala@gmail.com',
    maintainer='Alex Clark',
    maintainer_email='aclark@aclark.net',
    url='https://github.com/jazzband/django-axes',
    license='MIT',
    package_dir={'axes': 'axes'},
    install_requires=[
        'pytz',
        'django-appconf',
        'django-ipware>=2.0.2',
        'win_inet_pton ; python_version < "3.4" and sys_platform == "win32"',
    ],
    include_package_data=True,
    packages=find_packages(),
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 1.11',
        'Framework :: Django :: 2.0',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Internet :: Log Analysis',
        'Topic :: Security',
        'Topic :: System :: Logging',
    ],
    zip_safe=False,
)



from __future__ import unicode_literals

from .test_settings import *  # pylint: disable=unused-wildcard-import

AXES_CACHE = 'axes'

CACHES = {
    'axes': {
        'BACKEND': 'django.core.cache.backends.locmem.LocMemCache'
    }
}
